==> vue-list-2.8.0.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/list/vue";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

import "@dftvue2-opentiny/vue-theme-mobile/list/index.css";
var __vue2_script = defineComponent({
  name: $prefix + "List",
  props: {
    content: {
      type: String,
      default: ""
    },
    subText: {
      type: String,
      default: ""
    },
    contentDes: {
      type: String,
      default: ""
    },
    list: {
      type: Boolean,
      default: false
    },
    id: {
      type: [Number, String],
      default: ""
    }
  },
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-list",
    class: {
      "is-show-prefix": _vm.slots.prefix,
      "is-padding": _vm.list
    },
    on: {
      "click": _vm.clickList
    }
  }, [_vm.slots.prefix ? _c("div", {
    staticClass: "tiny-mobile-list__prefix"
  }, [_vm._t("prefix")], 2) : _vm._e(), _c("div", {
    staticClass: "tiny-mobile-list__content"
  }, [_c("div", {
    staticClass: "tiny-mobile-list__content-text"
  }, [_vm._t("default", function() {
    return [_c("span", {
      staticClass: "tiny-mobile-list__main-text"
    }, [_vm._v(_vm._s(_vm.content))])];
  }), _vm.subText ? _c("span", {
    staticClass: "tiny-mobile-list__sub-text"
  }, [_vm._v(_vm._s(_vm.subText))]) : _vm._e()], 2), _vm.slots.description ? _c("div", {
    staticClass: "tiny-mobile-list__content-des"
  }, [_vm._t("description")], 2) : _vm._e(), _vm.contentDes ? _c("p", {
    staticClass: "tiny-mobile-list__content-des"
  }, [_vm._v(" " + _vm._s(_vm.contentDes) + " ")]) : _vm._e()]), _vm.slots.suffix ? _c("div", {
    staticClass: "tiny-mobile-list__suffix"
  }, [_vm._t("suffix")], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var List = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.8.0";
List.install = function(Vue) {
  Vue.component(List.name, List);
};
List.version = version;
export {
  List as default
};

==> vue-list-2.21.0.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/list/vue';
import '@opentinyvue/vue-theme-mobile/list/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "List",
  props: {
    content: {
      type: String,
      default: ""
    },
    subText: {
      type: String,
      default: ""
    },
    contentDes: {
      type: String,
      default: ""
    },
    list: {
      type: Boolean,
      default: false
    },
    id: {
      type: [Number, String],
      default: ""
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-list",
    class: {
      "is-show-prefix": _vm.slots.prefix,
      "is-padding": _vm.list
    },
    on: {
      "click": _vm.clickList
    }
  }, [_vm.slots.prefix ? _c("div", {
    staticClass: "tiny-mobile-list__prefix"
  }, [_vm._t("prefix")], 2) : _vm._e(), _c("div", {
    staticClass: "tiny-mobile-list__content"
  }, [_c("div", {
    staticClass: "tiny-mobile-list__content-text"
  }, [_vm._t("default", function() {
    return [_c("span", {
      staticClass: "tiny-mobile-list__main-text"
    }, [_vm._v(_vm._s(_vm.content))])];
  }), _vm.subText ? _c("span", {
    staticClass: "tiny-mobile-list__sub-text"
  }, [_vm._v(_vm._s(_vm.subText))]) : _vm._e()], 2), _vm.slots.description ? _c("div", {
    staticClass: "tiny-mobile-list__content-des"
  }, [_vm._t("description")], 2) : _vm._e(), _vm.contentDes ? _c("p", {
    staticClass: "tiny-mobile-list__content-des"
  }, [_vm._v(" " + _vm._s(_vm.contentDes) + " ")]) : _vm._e()]), _vm.slots.suffix ? _c("div", {
    staticClass: "tiny-mobile-list__suffix"
  }, [_vm._t("suffix")], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var List = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.21.0";
List.install = function(Vue) {
  Vue.component(List.name, List);
};
List.version = version;

export { List as default };
